@@ -265,11 +265,11 @@ class AgendaDocument(TextDocument):
 
     '''Initializes a template.<br/>
     This method does the following tasks:<br/>
-    Get a Time and Date format for the document, and retrieve the null
+    get a Time and Date format for the document, and retrieve the null
     date of the document (which is document-specific).<br/>
     Initializes the Items Cache map.
     Analyses the document:<br/>
-    -find all "fille-ins" (appear as &gt;xxx&lt; in the document).
+    -find all "filled-ins" (appear as &gt;xxx&lt; in the document).
     -analyze all items sections (and the tables in them).
     -locate the titles and actualize them
     -analyze the topics table
@@ -410,7 +410,7 @@ class AgendaDocument(TextDocument):
     '''
     create the minutes for the given topics or remove the minutes
     section from the document.
-    If no topics are supplied, or the user specified not to create minuts,
+    If no topics are supplied, or the user specified not to create minutes,
     the minutes section will be removed,
     @param topicsData supplies PropertyValue arrays containing
     the values for the topics.
@@ -514,7 +514,7 @@ class AgendaDocument(TextDocument):
 
     '''given a text range and a text, fills the given
     text range with the given text.
-    If the given text is empty, uses a placeholder with the giveb
+    If the given text is empty, uses a placeholder with the given
     placeholder text.
     @param range text range to fill
     @param text the text to fill to the text range object.
@@ -724,7 +724,7 @@ class Topics(object):
     We hold the format of the last row, because one might wish to give it
     a special format, other than the one on the bottom of each topic.
     The left and right borders of the whole table are, on the other side,
-    part of the topics rows format, and need not be preserved separateley.
+    part of the topics rows format, and need not be preserved separately.
     '''
     table = None
     lastRowFormat = []
@@ -790,7 +790,7 @@ class Topics(object):
     This is used in order to refresh the topic/responsible/duration data
     in the preview document, in response to a change in the gui (by the user)
     Since the structure of the topics table is flexible,
-    The Topics object, which analyzed the structure of the topics table appon
+    The Topics object, which analyzed the structure of the topics table upon
     initialization, refreshes the approperiate cell.
     '''
     def writeCell(self, row, column, data):
@@ -824,10 +824,10 @@ class Topics(object):
     Note this method does only reducing - if
     the number of topics given is greater than the
     number of actual topics it does *not* add
-    rows !
+    rows!
     Note also that the first topic will never be removed.
     If the table contains no topics, the whole section will
-    be removed uppon finishing.
+    be removed upon finishing.
     The reason for that is a "table-design" one: the first topic is
     maintained in order to be able to add rows with a design of this topic,
     and not of the header row.
